@@ -19,8 +19,6 @@ class ZoomMeetings:
         self.email = user_email
 
     def CreateMeeting(self,date,topic,meeting_duration,meeting_password):
-        print(self.request_token.decode("utf-8"))
-        print(self.email)
         required_date_format = date.strftime("%Y-%m-%dT%H:%M:%SZ")
         url = 'https://api.zoom.us/v2/users/'+self.email+'/meetings'
         jsonObj = {"topic": topic, "start_time":required_date_format,"duration":meeting_duration,"password":meeting_password}
